You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@whimsical.apache.org by se...@apache.org on 2019/04/26 12:59:14 UTC

[whimsy] branch master updated: Preserve nbsp

This is an automated email from the ASF dual-hosted git repository.

sebb pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git


The following commit(s) were added to refs/heads/master by this push:
     new 9527c76  Preserve nbsp
9527c76 is described below

commit 9527c76bab53c332ebc81a7c0b2ce1ac7f03c124
Author: Sebb <se...@apache.org>
AuthorDate: Fri Apr 26 13:54:47 2019 +0100

    Preserve nbsp
---
 tools/collate_minutes.rb | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tools/collate_minutes.rb b/tools/collate_minutes.rb
index b423a80..ea20cc7 100755
--- a/tools/collate_minutes.rb
+++ b/tools/collate_minutes.rb
@@ -145,13 +145,13 @@ cinfo['committees'].each do |id,v|
   site[id] = {:name => v['display_name'], :link => v['site'], :text => v['description']}
 end
 
 # parse the calendar for layout info (note: hack for &raquo)
 CALENDAR = URI.parse 'https://www.apache.org/foundation/board/calendar.html'
 http = Net::HTTP.new(CALENDAR.host, CALENDAR.port)
 http.use_ssl = true
 http.verify_mode = OpenSSL::SSL::VERIFY_NONE
 get = Net::HTTP::Get.new CALENDAR.request_uri
-$calendar = Nokogiri::HTML(http.request(get).body.gsub('&raquo','&#187;'))
+$calendar = Nokogiri::HTML(http.request(get).body.gsub('&raquo','&#187;').gsub('&nbsp;','&#160;'))
 
 # add some style
 style = Nokogiri::XML::Node.new "style", $calendar
@@ -145,13 +145,13 @@ cinfo['committees'].each do |id,v|
 end
 
-# parse the calendar for layout info (note: hack for &raquo)
+# parse the calendar for layout info (note: hack for &raquo and &nbsp;)
 CALENDAR = URI.parse 'https://www.apache.org/foundation/board/calendar.html'
 http = Net::HTTP.new(CALENDAR.host, CALENDAR.port)